@@ -2,7 +2,7 @@
   mxBeeBase -- BeeBase C extension
 
   Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2012, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2013, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author (mailto:mal@lemburg.com).
 
@@ -34,7 +34,7 @@
 #include "mxBeeBase.h"
 
 /* Version number: Major.Minor.Patchlevel */
-#define MXBEEBASE_VERSION "3.2.4"
+#define MXBEEBASE_VERSION "3.2.6"
 
 /* Define these to have the module use free lists (saves malloc calls) */
 /*#define MXBEEINDEX_FREELIST*/
@@ -47,7 +47,7 @@ static char *Module_docstring =
  MXBEEBASE_MODULE" -- BeeBase objects and functions. Version "MXBEEBASE_VERSION"\n\n"
 
  "Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com\n"
- "Copyright (c) 2000-2012, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
+ "Copyright (c) 2000-2013, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
  "                 All Rights Reserved\n\n"
  "See the documentation for further information on copyrights,\n"
  "or contact the author."
@@ -1317,8 +1317,26 @@ PyTypeObject mxBeeIndex_Type = {
     0,					/*tp_getattro*/
     0,					/*tp_setattro*/
     0,					/*tp_as_buffer*/
-    0,					/*tp_xxx4*/
-    0					/*tp_doc*/
+    Py_TPFLAGS_DEFAULT,			/*tp_flags*/
+    0,					/* tp_doc */
+    0,					/* tp_traverse */
+    0,					/* tp_clear */
+    0,					/* tp_richcompare */
+    0,					/* tp_weaklistoffset */
+    0,					/* tp_iter */
+    0,					/* tp_iternext */
+    mxBeeIndex_Methods,			/* tp_methods */
+    0,					/* tp_members */
+    0,					/* tp_getset */
+    0,					/* tp_base */
+    0,					/* tp_dict */
+    0,					/* tp_descr_get */
+    0,					/* tp_descr_set */
+    0,					/* tp_dictoffset */
+    0,					/* tp_init */
+    0,					/* tp_alloc */
+    0,					/* tp_new */
+    0,					/* tp_free */
 };
 
 /* Python Method Table */
@@ -1670,8 +1688,26 @@ PyTypeObject mxBeeCursor_Type = {
     0,					/*tp_getattro*/
     0,					/*tp_setattro*/
     0,					/*tp_as_buffer*/
-    0,					/*tp_xxx4*/
-    0					/*tp_doc*/
+    Py_TPFLAGS_DEFAULT,			/*tp_flags*/
+    0,					/* tp_doc */
+    0,					/* tp_traverse */
+    0,					/* tp_clear */
+    0,					/* tp_richcompare */
+    0,					/* tp_weaklistoffset */
+    0,					/* tp_iter */
+    0,					/* tp_iternext */
+    mxBeeCursor_Methods,		/* tp_methods */
+    0,					/* tp_members */
+    0,					/* tp_getset */
+    0,					/* tp_base */
+    0,					/* tp_dict */
+    0,					/* tp_descr_get */
+    0,					/* tp_descr_set */
+    0,					/* tp_dictoffset */
+    0,					/* tp_init */
+    0,					/* tp_alloc */
+    0,					/* tp_new */
+    0,					/* tp_free */
 };
 
 /* Python Method Table */
