@@ -2,7 +2,7 @@
   mxProxy -- Proxy wrapper type
 
   Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2013, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author (mailto:mal@lemburg.com).
 
@@ -34,7 +34,7 @@
 #include "mxProxy.h"
 
 /* Version number: Major.Minor.Patchlevel */
-#define MXPROXY_VERSION "3.2.1"
+#define MXPROXY_VERSION "3.2.6"
 
 /* Define these to have the module use free lists (saves malloc calls) */
 #define MXPROXY_FREELIST
@@ -46,7 +46,7 @@ static char *Module_docstring =
  MXPROXY_MODULE" -- Generic proxy wrapper type. Version "MXPROXY_VERSION"\n\n"
 
  "Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com\n"
- "Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
+ "Copyright (c) 2000-2013, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
  "                 All Rights Reserved\n\n"
  "See the documentation for further information on copyrights,\n"
  "or contact the author."
@@ -1415,8 +1415,26 @@ PyTypeObject mxProxy_Type = {
     mxProxy_GetattrObject,		/*tp_getattro*/
     mxProxy_SetattrObject,		/*tp_setattro*/
     0,					/*tp_as_buffer*/
-    0,					/*tp_xxx4*/
-    0					/*tp_doc*/
+    Py_TPFLAGS_DEFAULT,			/*tp_flags*/
+    0,					/* tp_doc */
+    0,					/* tp_traverse */
+    0,					/* tp_clear */
+    0,					/* tp_richcompare */
+    0,					/* tp_weaklistoffset */
+    0,					/* tp_iter */
+    0,					/* tp_iternext */
+    mxProxy_Methods,			/* tp_methods */
+    0,					/* tp_members */
+    0,					/* tp_getset */
+    0,					/* tp_base */
+    0,					/* tp_dict */
+    0,					/* tp_descr_get */
+    0,					/* tp_descr_set */
+    0,					/* tp_dictoffset */
+    0,					/* tp_init */
+    0,					/* tp_alloc */
+    0,					/* tp_new */
+    0,					/* tp_free */
 };
 
 /* Python Method Table
