@@ -2,7 +2,7 @@
   mxQueue -- A queue implementation
 
   Copyright (c) 1999-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2013, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author (mailto:mal@lemburg.com).
 
@@ -33,7 +33,7 @@
 #include "mx.h"
 #include "mxQueue.h"
 
-#define MXQUEUE_VERSION "3.2.1"
+#define MXQUEUE_VERSION "3.2.6"
 
 /* The minimal size of queues; must be > 1 */
 #define MINIMAL_QUEUESIZE	4
@@ -54,7 +54,7 @@ static char *Module_docstring =
  MXQUEUE_MODULE" -- A queue implementation. Version "MXQUEUE_VERSION"\n\n"
 
  "Copyright (c) 1999-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com\n"
- "Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
+ "Copyright (c) 2000-2013, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
  "                 All Rights Reserved\n\n"
  "See the documentation for further information on copyrights,\n"
  "or contact the author."
@@ -932,8 +932,26 @@ PyTypeObject mxQueue_Type = {
     0, 					/*tp_getattro*/
     0, 					/*tp_setattro*/
     0,					/*tp_as_buffer*/
-    0,					/*tp_xxx4*/
-    0					/*tp_doc*/
+    Py_TPFLAGS_DEFAULT,			/*tp_flags*/
+    0,					/* tp_doc */
+    0,					/* tp_traverse */
+    0,					/* tp_clear */
+    0,					/* tp_richcompare */
+    0,					/* tp_weaklistoffset */
+    0,					/* tp_iter */
+    0,					/* tp_iternext */
+    mxQueue_Methods,			/* tp_methods */
+    0,					/* tp_members */
+    0,					/* tp_getset */
+    0,					/* tp_base */
+    0,					/* tp_dict */
+    0,					/* tp_descr_get */
+    0,					/* tp_descr_set */
+    0,					/* tp_dictoffset */
+    0,					/* tp_init */
+    0,					/* tp_alloc */
+    0,					/* tp_new */
+    0,					/* tp_free */
 };
 
 /* Python Method Table */
