@@ -2,7 +2,7 @@
   mxURL -- An URL datatype
 
   Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2013, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author (mailto:mal@lemburg.com).
 
@@ -36,7 +36,7 @@
 #include <ctype.h>
 
 /* Version number: Major.Minor.Patchlevel */
-#define MXURL_VERSION "3.2.1"
+#define MXURL_VERSION "3.2.6"
 
 /* Define this to have the module use a free list for URLs */
 #define MXURL_FREELIST
@@ -56,7 +56,7 @@ static char *Module_docstring =
  "Version "MXURL_VERSION"\n\n"
 
  "Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com\n"
- "Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
+ "Copyright (c) 2000-2013, eGenix.com Software GmbH; mailto:info@egenix.com\n\n"
  "                 All Rights Reserved\n\n"
  "See the documentation for further information on copyrights,\n"
  "or contact the author."
@@ -2564,8 +2564,26 @@ PyTypeObject mxURL_Type = {
     0, 					/*tp_getattro*/
     0, 					/*tp_setattro*/
     0,					/*tp_as_buffer*/
-    0,					/*tp_xxx4*/
-    0					/*tp_doc*/
+    Py_TPFLAGS_DEFAULT,			/*tp_flags*/
+    0,					/* tp_doc */
+    0,					/* tp_traverse */
+    0,					/* tp_clear */
+    0,					/* tp_richcompare */
+    0,					/* tp_weaklistoffset */
+    0,					/* tp_iter */
+    0,					/* tp_iternext */
+    mxURL_Methods,			/* tp_methods */
+    0,					/* tp_members */
+    0,					/* tp_getset */
+    0,					/* tp_base */
+    0,					/* tp_dict */
+    0,					/* tp_descr_get */
+    0,					/* tp_descr_set */
+    0,					/* tp_dictoffset */
+    0,					/* tp_init */
+    0,					/* tp_alloc */
+    0,					/* tp_new */
+    0,					/* tp_free */
 };
 
 /* Python Method Table */
@@ -2786,7 +2804,9 @@ void mxURLModule_Cleanup(void)
 	mxURL_FreeList = NULL;
     }
 #endif
-    Py_XDECREF(mxURL_MIMEDict);
+    if (!mxPy_DECREF_Unsafe_AtExit()) {
+	Py_XDECREF(mxURL_MIMEDict);
+    }
     mxURL_MIMEDict = NULL;
 
     /* Reset mxURL_Initialized flag */
